@@ -48,6 +48,19 @@ function templates(tpl,key) {
             "id" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsUserAttribute",
             "title" : "casAppMetaDataOptionsUserAttribute"
          },
+         {
+            "default" : 1,
+            "get" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsAllowProxy",
+            "id" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsAllowProxy",
+            "title" : "casAppMetaDataOptionsAllowProxy",
+            "type" : "bool"
+         },
+         {
+            "get" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsSamlValidate",
+            "id" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsSamlValidate",
+            "title" : "casSrvMetaDataOptionsSamlValidate",
+            "type" : "bool"
+         },
          {
             "default" : -1,
             "get" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsLogout",
@@ -58,8 +71,7 @@ function templates(tpl,key) {
          {
             "get" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsAuthnLevel",
             "id" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsAuthnLevel",
-            "title" : "casAppMetaDataOptionsAuthnLevel",
-            "type" : "intOrNull"
+            "title" : "casAppMetaDataOptionsAuthnLevel"
          },
          {
             "get" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsRule",
@@ -480,6 +492,34 @@ function templates(tpl,key) {
                   "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsUseNonce",
                   "title" : "oidcOPMetaDataOptionsUseNonce",
                   "type" : "bool"
+               },
+               {
+                  "default" : "userinfo",
+                  "get" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsUserinfoSource",
+                  "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsUserinfoSource",
+                  "select" : [
+                     {
+                        "k" : "userinfo",
+                        "v" : "Userinfo endpoint"
+                     },
+                     {
+                        "k" : "id_token",
+                        "v" : "ID Token"
+                     },
+                     {
+                        "k" : "access_token",
+                        "v" : "Access Token"
+                     }
+                  ],
+                  "title" : "oidcOPMetaDataOptionsUserinfoSource",
+                  "type" : "select"
+               },
+               {
+                  "default" : 0,
+                  "get" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsNoJwtHeader",
+                  "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsNoJwtHeader",
+                  "title" : "oidcOPMetaDataOptionsNoJwtHeader",
+                  "type" : "bool"
                }
             ],
             "id" : "oidcOPMetaDataOptionsProtocol",
@@ -646,6 +686,13 @@ function templates(tpl,key) {
                   "title" : "oidcRPMetaDataOptionsRefreshToken",
                   "type" : "bool"
                },
+               {
+                  "default" : 0,
+                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsNoJwtHeader",
+                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsNoJwtHeader",
+                  "title" : "oidcRPMetaDataOptionsNoJwtHeader",
+                  "type" : "bool"
+               },
                {
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsUserIDAttr",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsUserIDAttr",
@@ -711,6 +758,12 @@ function templates(tpl,key) {
                   "title" : "oidcRPMetaDataOptionsAllowOffline",
                   "type" : "bool"
                },
+               {
+                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAllowNativeSso",
+                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAllowNativeSso",
+                  "title" : "oidcRPMetaDataOptionsAllowNativeSso",
+                  "type" : "bool"
+               },
                {
                   "default" : 0,
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAllowPasswordGrant",
@@ -733,8 +786,7 @@ function templates(tpl,key) {
                {
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAuthnLevel",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAuthnLevel",
-                  "title" : "oidcRPMetaDataOptionsAuthnLevel",
-                  "type" : "intOrNull"
+                  "title" : "oidcRPMetaDataOptionsAuthnLevel"
                },
                {
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsRule",
@@ -2021,8 +2073,7 @@ function templates(tpl,key) {
                {
                   "get" : tpl+"s/"+key+"/"+"samlSPMetaDataOptionsAuthnLevel",
                   "id" : tpl+"s/"+key+"/"+"samlSPMetaDataOptionsAuthnLevel",
-                  "title" : "samlSPMetaDataOptionsAuthnLevel",
-                  "type" : "intOrNull"
+                  "title" : "samlSPMetaDataOptionsAuthnLevel"
                },
                {
                   "get" : tpl+"s/"+key+"/"+"samlSPMetaDataOptionsRule",
